package assertions;

/**
	Controls which types of assertions are checked, as well as methods that
	can be used to check them.

	Copyright (C) 1999 by James MacKay
*/
public final class Assert
{
	/**
		These constants control which types of assertions are actually checked:
	*/
	public static final boolean preconds  = true;
	public static final boolean checks    = true;
	public static final boolean postconds = true;

	/**
		Alternate names for the above constants - don't modify the values of these:
	*/
	public static final boolean preconditions = preconds;
	public static final boolean postconditions = postconds;

	/**
		Throws a PreconditionFailedException if and only if theCondition is false.
	*/
	public static final void require(boolean theCondition)
	{
		if (preconds && !theCondition)
		{
			throw new PreconditionFailedException();
		}
	}
	/**
		Throws a PreconditionFailedException constructed from theMessage if and
		only if theCondition is false.
	*/
	public static final void require(boolean theCondition, String theMessage)
	{
		if (preconds && !theCondition)
		{
			throw new PreconditionFailedException(theMessage);
		}
	}

	/**
		Throws an AssertionFailedException if and only if theCondition is false.
	*/
	public static final void check(boolean theCondition)
	{
		if (checks && !theCondition)
		{
			throw new AssertionFailedException();
		}
	}
	/**
		Throws an AssertionFailedException constructed from theMessage if and
		only if theCondition is false.
	*/
	public static final void check(boolean theCondition, String theMessage)
	{
		if (checks && !theCondition)
		{
			throw new AssertionFailedException(theMessage);
		}
	}

 	/**
		Throws a PostconditionFailedException if and only if theCondition is false.
	*/
	public static final void ensure(boolean theCondition)
	{
		if (postconds && !theCondition)
		{
			throw new PostconditionFailedException();
		}
	}
 	/**
		Throws a PostconditionFailedException constructed from theMessage if and
		only if theCondition is false.
	*/
	public static final void ensure(boolean theCondition, String theMessage)
	{
		if (postconds && !theCondition)
		{
			throw new PostconditionFailedException(theMessage);
		}
	}

}	// class Assert
