package assertions;

/**
	Used to test the Assert class
*/
public class Tester
{
	/**
		Creates a Tester object and runs all of its tests.
	*/
	public static void main(String[] args)
	{
		Tester t = new Tester();
		t.testAll();
	}

	/**
		Default constructor.
	*/
	public Tester()
	{
		// empty
	}

	/**
		Runs all of this object's tests.
	*/
	public void testAll()
	{
		testPreconditions();
		testChecks();
		testPostconditions();
	}

	/**
		Tests the handling of preconditions.
	*/
	public void testPreconditions()
	{
		// these preconditions should never fail:
		Assert.require(0 == 0, "0 == 0");
		Assert.require(true);

		// these preconditions should fail iff preconditions are being checked:
		try
		{
			Assert.require(1 < 1);
			System.out.println("Preconditions are NOT being checked - " +
								"the precondition '1 < 1' did not fail");
		}
		catch (PreconditionFailedException ex)
		{
			System.out.println("Preconditions are being checked - " +
								"the precondition '1 < 1' failed: " +
								ex.getMessage());
		}
		try
		{
			Assert.require(true == !true, "true == !true");
			System.out.println("Preconditions are NOT being checked - " +
								"the precondition 'true == !true' did not fail");
		}
		catch (PreconditionFailedException ex)
		{
			System.out.println("Preconditions are being checked - " +
								"the precondition 'true == !true' failed: " +
								ex.getMessage());
		}
	}	// void testPreconditions()

	/**
		Tests the handling of assertion checks.
	*/
	public void testChecks()
	{
		// these assertion checks should never fail:
		Assert.check(0 == 0, "0 == 0");
		Assert.check(true);

		// these assertion checks should fail iff assertions are being checked:
		try
		{
			Assert.check(1 < 1);
			System.out.println("Assertions are NOT being checked - " +
								"the assertion '1 < 1' did not fail");
		}
		catch (AssertionFailedException ex)
		{
			System.out.println("Assertions are being checked - " +
								"the assertion '1 < 1' failed: " +
								ex.getMessage());
		}
		try
		{
			Assert.check(true == !true, "true == !true");
			System.out.println("Assertions are NOT being checked - " +
								"the assertion 'true == !true' did not fail");
		}
		catch (AssertionFailedException ex)
		{
			System.out.println("Assertions are being checked - " +
								"the assertion 'true == !true' failed: " +
								ex.getMessage());
		}
	}	// void testChecks()

	/**
		Tests the handling of postconditions.
	*/
	public void testPostconditions()
	{
		// these postconditions should never fail:
		Assert.ensure(0 == 0, "0 == 0");
		Assert.ensure(true);

		// these postconditions should fail iff postconditions are being checked:
		try
		{
			Assert.ensure(1 < 1);
			System.out.println("Postconditions are NOT being checked - " +
								"the postcondition '1 < 1' did not fail");
		}
		catch (PostconditionFailedException ex)
		{
			System.out.println("Postconditions are being checked - " +
								"the postcondition '1 < 1' failed: " +
								ex.getMessage());
		}
		try
		{
			Assert.ensure(true == !true, "true == !true");
			System.out.println("Postconditions are NOT being checked - " +
								"the postcondition 'true == !true' did not fail");
		}
		catch (PostconditionFailedException ex)
		{
			System.out.println("Postconditions are being checked - " +
								"the postcondition 'true == !true' failed: " +
								ex.getMessage());
		}
	}	// void testPostconditions()

}
